#
# spec file for package rye
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rye
Version:        0.44.0
Release:        1.1
Summary:        Hassle-free Python project manager in Rust
License:        MIT
URL:            https://github.com/astral-sh/rye
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        https://github.com/spdx/license-list-data/archive/refs/tags/v3.25.0.tar.gz#/licenses.tar.gz
BuildRequires:  cargo >= 1.77
BuildRequires:  cargo-packaging
BuildRequires:  cmake
BuildRequires:  zstd
Requires:       python3
Recommends:     uv

%description
Rye is a comprehensive project and package management solution for Python. Born
from its creator's desire to establish a one-stop-shop for all Python users,
Rye provides a unified experience to install and manage Python installations,
pyproject.toml based projects, dependencies and virtualenvs seamlessly. It's
designed to accommodate complex projects, monorepos and to facilitate global
tool installations.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       %{name}
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       %{name}
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%package        bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       %{name}
Requires:       bash-completion
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%prep
%autosetup -p1 -a1
# license crate feature 'offline' is bogus and not implemented
pushd vendor/license-3.6.0+3.26.0
mkdir -p license-list-data
tar xf %{SOURCE2} -C license-list-data --strip-components=1
popd

%build
pushd rye
%{cargo_build}
popd

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 -t %{buildroot}%{_bindir}/ %{_builddir}/%{name}-%{version}/target/release/rye

export PATH="%{buildroot}%{_bindir}:${PATH}"
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions
rye self completion -s bash > %{buildroot}%{_datadir}/bash-completion/completions/%{name}
rye self completion -s fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
rye self completion -s zsh  > %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

# Tests require network
#%%check
#%%cargo_test

%files
%license LICENSE
%doc README.md
%{_bindir}/rye

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Thu Jun  5 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 0.44.0:
  * Attempt to build against Rust 1.84 (#1464)
  * Upgrade to `actions/upload-artifact@v4` (#1463)
  * Prep for v0.44.0 release (#1462)
  * Sync UV Releases (#1461)
  * Sync Python Releases (#1450)
  * Update bundled uv version to v0.6.2 (#1445)
  * Set Rust toolchain in `rust-toolchain.toml` (#1460)
  * Bump bundled Ruff version to 0.9.6 (#1457)
  * Fix lint errors from Rust 1.85 (#1459)
  * fix linter errors (unnecessary_map_or) (#1458)
  * Upgrade runners to `macos-14` (#1443)
* Tue May 13 2025 Daniel Garcia <daniel.garcia@suse.com>
- Update to version 0.43.0 (bsc#1243086):
  * Fix compatible toolchain to allow Python 3.13 by @PushUpek in #1429
  * Ignore free-threaded CPython builds by @Alexis-D in #1437
  * Bump bundled Ruff version to v0.8.2 by @charliermarsh in #1440
  * Add support for Python 3.9.21, 3.10.16, 3.11.11, 3.12.8, and 3.13.1 by @github-actions in #1439
  * Upgrade bundled uv version to v0.5.7 by @github-actions in #1424
* Sat Oct 26 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 0.42.0:
  * Bump bundled Ruff version to v0.7.0
  * Bump bundled uv version to v0.4.25
  * Add a uv banner to the Rye README
- Update vendored dependencies.
* Sun Oct 13 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update vendored dependencies.
- Update license data to version 3.25.0
  * ./licenses.tar.gz
* Mon Oct  7 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 0.41.0:
  * Restore hash annotations in lockfile
* Tue Sep 24 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Completion packages require the main package as well
* Mon Sep 23 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 0.40.0:
  * Remove pip-tools support; use uv for all operations
  * Respect exclusions when generating hashes
  * List all existing tool references on rye toolchain remove
  * Update bundled Ruff version to v0.6.3
  * Fix a few regex inefficiencies
  * Never modify or delete the virtualenv in rye list
  * Use inspect_err over map_err
  * Upgrade bundled Python releases
  * Upgrade bundled uv version to v0.4.15
* Sun Aug  4 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Initial spec for rye
